#[non_exhaustive]pub enum ImportJobView {
Unspecified,
Basic,
Full,
UnknownValue(UnknownValue),
}Expand description
Specifies the types of import job views that provide complete or partial details of an import job.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The import job view is not specified. The API displays the basic view by default.
Basic
The import job view includes basic metadata of an import job. This view does not include payload information.
Full
The import job view includes all metadata of an import job.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ImportJobView::value or ImportJobView::name.
Implementations