#[non_exhaustive]pub enum LicenseType {
Unspecified,
Default,
BringYourOwnLicense,
UnknownValue(UnknownValue),
}Expand description
The License type for premium images (RHEL, RHEL for SAP, SLES, SLES for SAP, Windows Server).
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified (default value).
Default
Default Google Cloud licensing plan. Licensing is charged per usage. This a good value to start with.
BringYourOwnLicense
Bring-your-own-license (BYOL) plan. User provides the OS license.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LicenseType::value or LicenseType::name.
Implementations