#[non_exhaustive]pub struct GroupPreferenceSetFinding {
pub display_name: String,
pub description: String,
pub machine_preferences: Option<VirtualMachinePreferences>,
pub monthly_cost_total: Option<Money>,
pub monthly_cost_compute: Option<Money>,
pub monthly_cost_os_license: Option<Money>,
pub monthly_cost_network_egress: Option<Money>,
pub monthly_cost_storage: Option<Money>,
pub monthly_cost_other: Option<Money>,
pub compute_engine_finding: Option<ComputeEngineFinding>,
pub vmware_engine_finding: Option<VmwareEngineFinding>,
pub sole_tenant_finding: Option<SoleTenantFinding>,
/* private fields */
}Expand description
Summary Findings for a specific Group/PreferenceSet combination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringDisplay Name of the Preference Set
description: StringDescription for the Preference Set.
machine_preferences: Option<VirtualMachinePreferences>A set of preferences that applies to all machines in the context.
monthly_cost_total: Option<Money>Total monthly cost for this preference set.
monthly_cost_compute: Option<Money>Compute monthly cost for this preference set.
monthly_cost_os_license: Option<Money>Licensing monthly cost for this preference set.
monthly_cost_network_egress: Option<Money>Network Egress monthly cost for this preference set.
monthly_cost_storage: Option<Money>Storage monthly cost for this preference set.
monthly_cost_other: Option<Money>Miscellaneous monthly cost for this preference set.
compute_engine_finding: Option<ComputeEngineFinding>A set of findings that applies to Compute Engine machines in the input.
vmware_engine_finding: Option<VmwareEngineFinding>A set of findings that applies to VMWare machines in the input.
sole_tenant_finding: Option<SoleTenantFinding>A set of findings that applies to Sole-Tenant machines in the input.
Implementations
Sourceimpl GroupPreferenceSetFinding
impl GroupPreferenceSetFinding
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = GroupPreferenceSetFinding::new().set_display_name("example");Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = GroupPreferenceSetFinding::new().set_description("example");Sourcepub fn set_machine_preferences<T>(self, v: T) -> Selfwhere
T: Into<VirtualMachinePreferences>,
pub fn set_machine_preferences<T>(self, v: T) -> Selfwhere
T: Into<VirtualMachinePreferences>,
Sets the value of machine_preferences.
Example
use google_cloud_migrationcenter_v1::model::VirtualMachinePreferences;
let x = GroupPreferenceSetFinding::new().set_machine_preferences(VirtualMachinePreferences::default()/* use setters */);Sourcepub fn set_or_clear_machine_preferences<T>(self, v: Option<T>) -> Selfwhere
T: Into<VirtualMachinePreferences>,
pub fn set_or_clear_machine_preferences<T>(self, v: Option<T>) -> Selfwhere
T: Into<VirtualMachinePreferences>,
Sets or clears the value of machine_preferences.
Example
use google_cloud_migrationcenter_v1::model::VirtualMachinePreferences;
let x = GroupPreferenceSetFinding::new().set_or_clear_machine_preferences(Some(VirtualMachinePreferences::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_machine_preferences(None::<VirtualMachinePreferences>);Sourcepub fn set_monthly_cost_total<T>(self, v: T) -> Self
pub fn set_monthly_cost_total<T>(self, v: T) -> Self
Sets the value of monthly_cost_total.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_total(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_total<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_total<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_total.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_total(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_total(None::<Money>);Sourcepub fn set_monthly_cost_compute<T>(self, v: T) -> Self
pub fn set_monthly_cost_compute<T>(self, v: T) -> Self
Sets the value of monthly_cost_compute.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_compute(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_compute<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_compute<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_compute.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_compute(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_compute(None::<Money>);Sourcepub fn set_monthly_cost_os_license<T>(self, v: T) -> Self
pub fn set_monthly_cost_os_license<T>(self, v: T) -> Self
Sets the value of monthly_cost_os_license.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_os_license(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_os_license<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_os_license<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_os_license.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_os_license(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_os_license(None::<Money>);Sourcepub fn set_monthly_cost_network_egress<T>(self, v: T) -> Self
pub fn set_monthly_cost_network_egress<T>(self, v: T) -> Self
Sets the value of monthly_cost_network_egress.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_network_egress(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_network_egress<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_network_egress<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_network_egress.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_network_egress(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_network_egress(None::<Money>);Sourcepub fn set_monthly_cost_storage<T>(self, v: T) -> Self
pub fn set_monthly_cost_storage<T>(self, v: T) -> Self
Sets the value of monthly_cost_storage.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_storage(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_storage<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_storage<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_storage.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_storage(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_storage(None::<Money>);Sourcepub fn set_monthly_cost_other<T>(self, v: T) -> Self
pub fn set_monthly_cost_other<T>(self, v: T) -> Self
Sets the value of monthly_cost_other.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_monthly_cost_other(Money::default()/* use setters */);Sourcepub fn set_or_clear_monthly_cost_other<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_monthly_cost_other<T>(self, v: Option<T>) -> Self
Sets or clears the value of monthly_cost_other.
Example
use google_cloud_type::model::Money;
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_other(Some(Money::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_monthly_cost_other(None::<Money>);Sourcepub fn set_compute_engine_finding<T>(self, v: T) -> Selfwhere
T: Into<ComputeEngineFinding>,
pub fn set_compute_engine_finding<T>(self, v: T) -> Selfwhere
T: Into<ComputeEngineFinding>,
Sets the value of compute_engine_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::ComputeEngineFinding;
let x = GroupPreferenceSetFinding::new().set_compute_engine_finding(ComputeEngineFinding::default()/* use setters */);Sourcepub fn set_or_clear_compute_engine_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<ComputeEngineFinding>,
pub fn set_or_clear_compute_engine_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<ComputeEngineFinding>,
Sets or clears the value of compute_engine_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::ComputeEngineFinding;
let x = GroupPreferenceSetFinding::new().set_or_clear_compute_engine_finding(Some(ComputeEngineFinding::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_compute_engine_finding(None::<ComputeEngineFinding>);Sourcepub fn set_vmware_engine_finding<T>(self, v: T) -> Selfwhere
T: Into<VmwareEngineFinding>,
pub fn set_vmware_engine_finding<T>(self, v: T) -> Selfwhere
T: Into<VmwareEngineFinding>,
Sets the value of vmware_engine_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::VmwareEngineFinding;
let x = GroupPreferenceSetFinding::new().set_vmware_engine_finding(VmwareEngineFinding::default()/* use setters */);Sourcepub fn set_or_clear_vmware_engine_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<VmwareEngineFinding>,
pub fn set_or_clear_vmware_engine_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<VmwareEngineFinding>,
Sets or clears the value of vmware_engine_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::VmwareEngineFinding;
let x = GroupPreferenceSetFinding::new().set_or_clear_vmware_engine_finding(Some(VmwareEngineFinding::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_vmware_engine_finding(None::<VmwareEngineFinding>);Sourcepub fn set_sole_tenant_finding<T>(self, v: T) -> Selfwhere
T: Into<SoleTenantFinding>,
pub fn set_sole_tenant_finding<T>(self, v: T) -> Selfwhere
T: Into<SoleTenantFinding>,
Sets the value of sole_tenant_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::SoleTenantFinding;
let x = GroupPreferenceSetFinding::new().set_sole_tenant_finding(SoleTenantFinding::default()/* use setters */);Sourcepub fn set_or_clear_sole_tenant_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<SoleTenantFinding>,
pub fn set_or_clear_sole_tenant_finding<T>(self, v: Option<T>) -> Selfwhere
T: Into<SoleTenantFinding>,
Sets or clears the value of sole_tenant_finding.
Example
use google_cloud_migrationcenter_v1::model::report_summary::SoleTenantFinding;
let x = GroupPreferenceSetFinding::new().set_or_clear_sole_tenant_finding(Some(SoleTenantFinding::default()/* use setters */));
let x = GroupPreferenceSetFinding::new().set_or_clear_sole_tenant_finding(None::<SoleTenantFinding>);Trait Implementations
Sourceimpl Clone for GroupPreferenceSetFinding
impl Clone for GroupPreferenceSetFinding
Sourcefn clone(&self) -> GroupPreferenceSetFinding
fn clone(&self) -> GroupPreferenceSetFinding
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more