#[non_exhaustive]pub struct CreateReportRequest {
pub parent: String,
pub report_id: String,
pub report: Option<Report>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a Report.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
report_id: StringRequired. User specified id for the report. It will become the last component of the report name. The id must be unique within the project, must conform with RFC-1034, is restricted to lower-cased letters, and has a maximum length of 63 characters. The id must match the regular expression: a-z?.
report: Option<Report>Required. The report resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateReportRequest
impl CreateReportRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_report_id<T: Into<String>>(self, v: T) -> Self
pub fn set_report_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_report<T>(self, v: T) -> Self
pub fn set_report<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_report<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_report<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateReportRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateReportRequest
impl Clone for CreateReportRequest
Sourcefn clone(&self) -> CreateReportRequest
fn clone(&self) -> CreateReportRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more