#[non_exhaustive]pub struct GenericPlatformDetails {
pub location: String,
/* private fields */
}Expand description
Generic platform details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: StringFree text representation of the machine location. The format of this field should not be relied on. Different VMs in the same location may have different string values for this field.
Implementations