#[non_exhaustive]pub struct ReportSummary {
pub all_assets_stats: Option<AssetAggregateStats>,
pub group_findings: Vec<GroupFinding>,
/* private fields */
}Expand description
Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.all_assets_stats: Option<AssetAggregateStats>Aggregate statistics for all the assets across all the groups.
group_findings: Vec<GroupFinding>Findings for each Group included in this report.
Implementations
Sourceimpl ReportSummary
impl ReportSummary
pub fn new() -> Self
Sourcepub fn set_all_assets_stats<T>(self, v: T) -> Selfwhere
T: Into<AssetAggregateStats>,
pub fn set_all_assets_stats<T>(self, v: T) -> Selfwhere
T: Into<AssetAggregateStats>,
Sets the value of all_assets_stats.
Example
ⓘ
use google_cloud_migrationcenter_v1::model::report_summary::AssetAggregateStats;
let x = ReportSummary::new().set_all_assets_stats(AssetAggregateStats::default()/* use setters */);Sourcepub fn set_or_clear_all_assets_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssetAggregateStats>,
pub fn set_or_clear_all_assets_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssetAggregateStats>,
Sets or clears the value of all_assets_stats.
Example
ⓘ
use google_cloud_migrationcenter_v1::model::report_summary::AssetAggregateStats;
let x = ReportSummary::new().set_or_clear_all_assets_stats(Some(AssetAggregateStats::default()/* use setters */));
let x = ReportSummary::new().set_or_clear_all_assets_stats(None::<AssetAggregateStats>);Sourcepub fn set_group_findings<T, V>(self, v: T) -> Self
pub fn set_group_findings<T, V>(self, v: T) -> Self
Sets the value of group_findings.
Example
ⓘ
use google_cloud_migrationcenter_v1::model::report_summary::GroupFinding;
let x = ReportSummary::new()
.set_group_findings([
GroupFinding::default()/* use setters */,
GroupFinding::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ReportSummary
impl Clone for ReportSummary
Sourcefn clone(&self) -> ReportSummary
fn clone(&self) -> ReportSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReportSummary
impl Debug for ReportSummary
Sourceimpl Default for ReportSummary
impl Default for ReportSummary
Sourcefn default() -> ReportSummary
fn default() -> ReportSummary
Returns the “default value” for a type. Read more
Sourceimpl Message for ReportSummary
impl Message for ReportSummary
Sourceimpl PartialEq for ReportSummary
impl PartialEq for ReportSummary
impl StructuralPartialEq for ReportSummary