#[non_exhaustive]pub struct Settings {
pub name: String,
pub preference_set: String,
/* private fields */
}Expand description
Describes the Migration Center settings related to the project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The name of the resource.
preference_set: StringThe preference set used by default for a project.
Implementations