#[non_exhaustive]pub struct UpdateGroupRequest {
pub update_mask: Option<FieldMask>,
pub group: Option<Group>,
pub request_id: String,
/* private fields */
}Expand description
A request to update a group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the
Group resource by the update.
The values specified in the update_mask are relative to the resource, not
the full request. A field will be overwritten if it is in the mask.
A single * value in the mask lets you to overwrite all fields.
group: Option<Group>Required. The group resource being updated.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateGroupRequest
impl UpdateGroupRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateGroupRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateGroupRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateGroupRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateGroupRequest
impl Clone for UpdateGroupRequest
Sourcefn clone(&self) -> UpdateGroupRequest
fn clone(&self) -> UpdateGroupRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more